@@ -29,6 +29,8 @@
 # The function .parseBoolean() is inspired by the function
 # parseBoolean() contained in the COBRA Toolbox.
 # The algorithm is the same.
+#
+# 2015-06-17 CJF: added handling for emtpy gprRule like "( )"
 
 
 .parseBoolean <- function(gprRule, tokens = "()&|~") {
@@ -41,6 +43,11 @@
   if ( is.na(gprRule) || (gprRule == "") ) {
       return(list(gene = "", rule = ""))
   }
+  
+  if( grepl("\\s*\\(\\s*\\)\\s*", gprRule) ){
+  	warning("found empty expression rule: '( )'. check if this is intended.")
+  	return(list(gene = "", rule = ""))
+  }
 
   # quit, if there is no gene association
 #  if ( (gprRule == "UNKNOWN") || (gprRule == "SPONTANEOUS") ) {
@@ -167,18 +174,6 @@
 
 
 
-
-
-
-
-
-
-
-
-
-
-
-
   
 #  for (i in 1:length(genes[[1]])) {
 #      #current_tok <- gsub("(^\\s+)|(\\s+$)", "", genes[[1]][i], perl = TRUE)
